import { DynamoDB } from 'aws-sdk';
import { withCors } from '../../utils/addingCors';

const dynamoDb = new DynamoDB.DocumentClient();
const tableName = process.env.TABLE_NAME;

export const handler = async (event: any) => {
  const contactId = event.pathParameters?.contactId;

  try {
    if (contactId) {
      // Fetch specific contact
      const result = await dynamoDb
        .get({
          TableName: tableName!,
          Key: { id: contactId },
        })
        .promise();

      if (!result.Item) {
        return withCors(404, { error: 'Contact not found' });
      }

      return withCors(200, result.Item);
    } else {
      // Fetch all contacts
      const result = await dynamoDb
        .scan({
          TableName: tableName!,
        })
        .promise();

      return withCors(200, result.Items || []);
    }
  } catch (error) {
    console.error('Error fetching contacts:', error);
    return withCors(500, { error: 'Could not fetch contacts' });
  }
};
